@@ -1,4 +1,3 @@
-import logging
 import re
 from dataclasses import dataclass
 from datetime import datetime, timezone
@@ -34,6 +33,7 @@ from serde import deserialize
 from metaphor.common.entity_id import EntityId, to_virtual_view_entity_id
 from metaphor.common.event_util import EventUtil
 from metaphor.common.extractor import BaseExtractor, RunConfig
+from metaphor.common.logging import get_logger
 
 from .generated.dbt_catalog import CatalogTable, DbtCatalog
 from .generated.dbt_manifest import (
@@ -44,8 +44,7 @@ from .generated.dbt_manifest import (
     ParsedSourceDefinition,
 )
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)
+logger = get_logger(__name__)
 
 
 @deserialize
@@ -299,8 +298,13 @@ class DbtExtractor(BaseExtractor):
             materialized = model.config.materialized
 
             if materialized:
+                try:
+                    type = DbtMaterializationType[materialized.upper()]
+                except KeyError:
+                    type = DbtMaterializationType.OTHER
+
                 dbt_model.materialization = DbtMaterialization(
-                    type=DbtMaterializationType[materialized.upper()],
+                    type=type,
                     target_dataset=str(
                         self._get_dataset_entity_id(
                             model.database, model.schema_, model.name
