@@ -1,16 +1,17 @@
-import logging
 from dataclasses import dataclass
 from typing import Dict, List, Optional, Tuple
 
 from snowflake.connector import SnowflakeConnection
 
 from metaphor.common.event_util import EventUtil
+from metaphor.common.logging import get_logger
 from metaphor.snowflake.auth import SnowflakeAuthConfig, connect
 from metaphor.snowflake.extractor import SnowflakeExtractor
 from metaphor.snowflake.utils import (
     DEFAULT_THREAD_POOL_SIZE,
     DatasetInfo,
     QueryWithParam,
+    SnowflakeTableType,
     async_execute,
 )
 
@@ -33,8 +34,7 @@ from serde import deserialize
 
 from metaphor.common.extractor import BaseExtractor
 
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.INFO)
+logger = get_logger(__name__)
 
 
 @deserialize
@@ -46,6 +46,9 @@ class SnowflakeProfileRunConfig(SnowflakeAuthConfig):
     # max number of concurrent queries to database
     max_concurrency: Optional[int] = DEFAULT_THREAD_POOL_SIZE
 
+    # exclude views from profiling
+    exclude_views: bool = True
+
 
 class SnowflakeProfileExtractor(BaseExtractor):
     """Snowflake data profile extractor"""
@@ -56,6 +59,7 @@ class SnowflakeProfileExtractor(BaseExtractor):
 
     def __init__(self):
         self.max_concurrency = None
+        self.exclude_views = None
         self._datasets: Dict[str, Dataset] = {}
 
     async def extract(
@@ -65,6 +69,7 @@ class SnowflakeProfileExtractor(BaseExtractor):
 
         logger.info("Fetching data profile from Snowflake")
         self.max_concurrency = config.max_concurrency
+        self.exclude_views = config.exclude_views
 
         conn = connect(config)
 
@@ -101,18 +106,29 @@ class SnowflakeProfileExtractor(BaseExtractor):
         tables: Dict[str, DatasetInfo] = {}
         for row in cursor:
             schema, name, table_type = row[0], row[1], row[2]
+            if self.exclude_views and table_type != SnowflakeTableType.BASE_TABLE.value:
+                # exclude both view and temporary table
+                continue
+
             full_name = SnowflakeExtractor.table_fullname(database, schema, name)
             self._datasets[full_name] = self._init_dataset(account, full_name)
             tables[full_name] = DatasetInfo(database, schema, name, table_type)
 
         return tables
 
+    FETCH_COLUMNS_QUERY = """
+        SELECT column_name, data_type, is_nullable
+        FROM information_schema.columns
+        WHERE table_schema = %s AND table_name = %s
+        ORDER BY ordinal_position
+        """
+
     def _fetch_columns_async(
         self, conn: SnowflakeConnection, tables: Dict[str, DatasetInfo]
     ) -> None:
         queries = {
             fullname: QueryWithParam(
-                SnowflakeExtractor.FETCH_COLUMNS_QUERY, (dataset.schema, dataset.name)
+                self.FETCH_COLUMNS_QUERY, (dataset.schema, dataset.name)
             )
             for fullname, dataset in tables.items()
         }
@@ -123,7 +139,8 @@ class SnowflakeProfileExtractor(BaseExtractor):
         for full_name, columns in results.items():
             dataset = tables[full_name]
             column_info = [
-                (column[1], column[2], column[5] == "YES") for column in columns
+                (name, data_type, nullable == "YES")
+                for name, data_type, nullable in columns
             ]
             column_info_map[full_name] = column_info
             profile_queries[full_name] = QueryWithParam(
